Sliders can now snap to arbitrary values
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The `~matplotlib.widgets.Slider` UI widget now accepts arrays for *valstep*.
This generalizes the previous behavior by allowing the slider to snap to
arbitrary values.
